@@ -12,7 +12,7 @@ use Data::Object::Library qw(Str);
 
 extends 'API::Client';
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 our $DEFAULT_URL = "https://graph.facebook.com";
 
@@ -95,7 +95,7 @@ API::Facebook - Facebook.com API Client
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -155,7 +155,7 @@ The debug attribute if true prints HTTP requests and responses to standard out.
     $facebook->fatal(1);
 
 The fatal attribute if true promotes 4xx and 5xx server response codes to
-exceptions, a L<API::Facebook::Exception> object.
+exceptions, a L<API::Client::Exception> object.
 
 =head2 retries
 
